@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from ConfigParser import ConfigParser
+from ConfigParser import SafeConfigParser
 
 
 class BaseParser:
@@ -9,7 +9,7 @@ class BaseParser:
         self._load_config()
 
     def _load_config(self):
-        self.raw_config = ConfigParser()
+        self.raw_config = SafeConfigParser()
         self.raw_config.read(self.config_file)
         self._parse_config()
 
@@ -17,4 +17,4 @@ class BaseParser:
         for section in self.raw_config.sections():
             self.config[section.lower()] = {}
             for k, v in self.raw_config.items(section):
-                self.config[section.lower()][k] = v.isdigit() and int(v) or v
\ No newline at end of file
+                self.config[section.lower()][k] = v.isdigit() and int(v) or v
